@@ -33,7 +33,7 @@ config_defaults = {
         "show_main_toolbar": True,
         "show_statusbar": True,
         "show_video_toolbar": False,
-        "size": [600, 371],
+        "size": [700, 433],
         "toolbar_style": gaupol.toolbar_styles.DEFAULT,
         },
     "capitalization": {
@@ -74,7 +74,7 @@ config_defaults = {
                         gaupol.fields.MAIN_TEXT,
                         gaupol.fields.TRAN_TEXT],
 
-        "framerate": aeidon.framerates.FPS_24,
+        "framerate": aeidon.framerates.FPS_23_976,
         "length_unit": gaupol.length_units.EM,
         "mode": aeidon.modes.TIME,
         "show_lengths_cell": True,
@@ -158,6 +158,15 @@ config_defaults = {
         "regex": False,
         "target": gaupol.targets.CURRENT,
         },
+    "speech_recognition": {
+        "acoustic_model": "",
+        "advance_length": 100,
+        "lang_model": "",
+        "noise_level": 256,
+        "phonetic_dict": "",
+        "silence_length": 300,
+        "use_custom_models": False,
+        },
     "spell_check": {
         "field": gaupol.fields.MAIN_TEXT,
         "inline": False,
@@ -172,7 +181,7 @@ config_defaults = {
         "maximized": False,
         "pages": [],
         "remove_blank": True,
-        "size": [gaupol.util.char_to_px(98), gaupol.util.lines_to_px(34)],
+        "size": [700, 433],
         "target": gaupol.targets.CURRENT,
         },
     }
@@ -330,6 +339,18 @@ class ConfigurationStore(gaupol.AttributeDictionary):
         method = getattr(obj, method_name)
         container.disconnect(signal, method)
 
+    def query_default(self, sections, option):
+        """Return default value of configuration option.
+
+        Raise :exc:`KeyError` if section or option not found.
+        """
+        if isinstance(sections, basestring):
+            sections = (sections,)
+        container = self._defaults
+        for section in sections:
+            container = container[section]
+        return container[option]
+
     def read_from_file(self):
         """Read values of configuration options from file.
 
@@ -340,7 +361,15 @@ class ConfigurationStore(gaupol.AttributeDictionary):
         if self.path is None: return
         if not os.path.isfile(self.path): return
         encoding = aeidon.util.get_default_encoding()
-        try: lines = codecs.open(self.path, "r", encoding).readlines()
+        try:
+            # Ignore all decoding errors, since all keys and all standard
+            # values are all ASCII. This will only mangle recent etc.
+            # filenames, which are always checked for existance anyway.
+            lines = codecs.open(self.path,
+                                "r",
+                                encoding,
+                                errors="ignore").readlines()
+
         except IOError:
             aeidon.util.print_read_io(sys.exc_info(), self.path)
             raise # IOError
@@ -365,11 +394,21 @@ class ConfigurationStore(gaupol.AttributeDictionary):
                 value = value.strip()
                 enum = enums.get(option, None)
                 try: value = json.loads(value, cls=EnumDecoder, enum=enum)
-                except ValueError:
+                except (AttributeError, ValueError):
                     print ("Failed to parse value '%s' of option '%s.%s' "
                            "from configuration file '%s'." % (
                             value, "::".join(sections), option, self.path))
 
+                    continue
+                if hasattr(container, option) and value is None:
+                    # Discard a None-value for all non-extension options.
+                    # None-values are not used for any options, but might
+                    # accidentally bet set in some corner or error cases.
+                    # By discarding them here, we ensure a clean start.
+                    print ("Discarding value '%s' of option '%s.%s' "
+                           "from configuration file '%s'." % (
+                            value, "::".join(sections), option, self.path))
+
                     continue
                 if not hasattr(container, option):
                     # Add attribute if it does not exist in container, which
