@@ -23,11 +23,20 @@ class TestModule(gaupol.TestCase):
     def test_bug_report_url(self):
         urllib2.urlopen(gaupol.BUG_REPORT_URL, timeout=10)
 
+    def test_extensions_url(self):
+        urllib2.urlopen(gaupol.EXTENSIONS_URL, timeout=10)
+
     def test_homepage_url(self):
         urllib2.urlopen(gaupol.HOMEPAGE_URL, timeout=10)
 
+    def test_preview_help_url(self):
+        urllib2.urlopen(gaupol.PREVIEW_HELP_URL, timeout=10)
+
     def test_regex_help_url(self):
         urllib2.urlopen(gaupol.REGEX_HELP_URL, timeout=10)
 
+    def test_speech_recognition_help_url(self):
+        urllib2.urlopen(gaupol.SPEECH_RECOGNITION_HELP_URL, timeout=10)
+
     def test_wiki_url(self):
         urllib2.urlopen(gaupol.WIKI_URL, timeout=10)
