@@ -47,6 +47,10 @@ class TestModule(gaupol.TestCase):
         gaupol.conf.editor.custom_font = None
         assert gaupol.util.get_font() == ""
 
+    def test_get_gst_version(self):
+        reload(gaupol.util)
+        assert gaupol.util.get_gst_version()
+
     def test_get_preview_command(self):
         gaupol.conf.preview.use_custom_command = True
         gaupol.conf.preview.force_utf_8 = False
@@ -58,6 +62,10 @@ class TestModule(gaupol.TestCase):
         gaupol.conf.preview.force_utf_8 = False
         gaupol.util.get_preview_command()
 
+    def test_get_pygst_version(self):
+        reload(gaupol.util)
+        assert gaupol.util.get_pygst_version()
+
     def test_get_text_view_size(self):
         text_view = gtk.TextView(gtk.TextBuffer())
         gaupol.util.get_text_view_size(text_view)
@@ -68,6 +76,10 @@ class TestModule(gaupol.TestCase):
         scroller.add(tree_view)
         gaupol.util.get_tree_view_size(tree_view)
 
+    def test_gst_available(self):
+        reload(gaupol.util)
+        assert gaupol.util.gst_available()
+
     def test_gtkspell_available(self):
         reload(gaupol.util)
         assert gaupol.util.gtkspell_available()
@@ -75,6 +87,9 @@ class TestModule(gaupol.TestCase):
     def test_lines_to_px(self):
         assert gaupol.util.lines_to_px(1) > 0
 
+    def test_pocketsphinx_available(self):
+        gaupol.util.pocketsphinx_available()
+
     def test_prepare_text_view__hide_lengths(self):
         gaupol.util.prepare_text_view(gtk.TextView())
         gaupol.conf.editor.show_lengths_edit = False
