@@ -73,6 +73,14 @@ def get_font():
             (gaupol.conf.editor.use_custom_font and
              gaupol.conf.editor.custom_font) else "")
 
+def get_gst_version():
+    """Return :mod:`gst` version number as string or ``None``."""
+    try:
+        import gst
+        return ".".join(map(str, gst.version()))
+    except Exception:
+        return None
+
 def get_preview_command():
     """Return command to use for lauching video player."""
     if gaupol.conf.preview.use_custom_command:
@@ -81,6 +89,14 @@ def get_preview_command():
         return gaupol.conf.preview.player.command_utf_8
     return gaupol.conf.preview.player.command
 
+def get_pygst_version():
+    """Return ``pygst`` version number as string or ``None``."""
+    try:
+        import gst
+        return ".".join(map(str, gst.pygst_version))
+    except Exception:
+        return None
+
 def get_text_view_size(text_view, font=""):
     """Return the width and height desired by `text_view`."""
     text_buffer = text_view.get_buffer()
@@ -99,6 +115,15 @@ def get_tree_view_size(tree_view):
     scroller.set_policy(*policy)
     return width, height
 
+@aeidon.deco.once
+def gst_available():
+    """Return ``True`` if :mod:`gst` module is available."""
+    try:
+        import gst
+        return True
+    except Exception:
+        return False
+
 @aeidon.deco.once
 def gtkspell_available():
     """Return ``True`` if :mod:`gtkspell` module is available."""
@@ -131,6 +156,15 @@ def lines_to_px(nlines, font=None):
     height = label.get_layout().get_pixel_size()[1]
     return int(round(nlines * height))
 
+@aeidon.deco.once
+def pocketsphinx_available():
+    """Return ``True`` if `pocketsphinx` gstreamer plugin is available."""
+    try:
+        import gst
+        return gst.plugin_load_by_name("pocketsphinx") is not None
+    except Exception:
+        return False
+
 def prepare_text_view(text_view):
     """Set spell-check, line-length margin and font properties."""
     if gaupol.util.gtkspell_available() and gaupol.conf.spell_check.inline:
